package Bencher::ScenarioR::DateTimeFormatDurationISO8601::Parsing;

our $VERSION = 0.001; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        arg_str    => "P1Y2M3DT4H5M6.7S",
        errors     => 6.2e-08,
        rate       => 26000,
        samples    => 23,
        time       => 38,
        vs_slowest => 1,
      },
      {
        arg_str    => "P1Y",
        errors     => 1.1e-06,
        rate       => 40000,
        samples    => 27,
        time       => 20,
        vs_slowest => 2,
      },
      {
        arg_str    => "PT1S",
        errors     => 5.3e-08,
        rate       => 55000,
        samples    => 20,
        time       => 18,
        vs_slowest => 2.1,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "DateTimeFormatDurationISO8601::Parsing",
                                          },
      "func.bencher_version"           => undef,
      "func.code_startup"              => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "sdbg",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "epb",
                                                                                "intel_pt",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 2462.902,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "sdbg",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "epb",
                                                                                "intel_pt",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => "2697.290",
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "sdbg",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "epb",
                                                                                "intel_pt",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 2612.011,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "sdbg",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "epb",
                                                                                "intel_pt",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => 2762.915,
                                              stepping                     => 4,
                                            },
                                          ],
      "func.elapsed_time"              => 0.102420806884766,
      "func.module_startup"            => undef,
      "func.module_versions"           => {
                                            "__PACKAGE__" => 1.041,
                                            "Bencher::Scenario::DateTimeFormatDurationISO8601::Parsing" => undef,
                                            "Benchmark::Dumb" => 0.111,
                                            "DateTime::Format::Duration::ISO8601" => 0.008,
                                            "Devel::Platform::Info" => 0.16,
                                            "perl" => "v5.26.1",
                                            "Sys::Info" => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => ["perl", ["perl"], "participant", [0], "dataset", [0]],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "sylvia",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-4.10.0-38-generic",
                                            kname    => "Linux",
                                            kvers    => "4.10.0-38-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 18.3,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 18.3 Sylvia \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.3 Sylvia\nRelease:\t18.3\nCodename:\tsylvia",
                                                          "uname -a"        => "Linux backpacker 4.10.0-38-generic #42~16.04.1-Ubuntu SMP Tue Oct 10 16:32:20 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "4.10.0-38-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 0,
      "func.scenario_module"           => "Bencher::Scenario::DateTimeFormatDurationISO8601::Parsing",
      "func.scenario_module_md5sum"    => "da08f7ab943f5d812e8ae8f9880b94e7",
      "func.scenario_module_mtime"     => 1531657962,
      "func.scenario_module_sha1sum"   => "f1126dcdc232d44b6b5464420d2137fa54d4765b",
      "func.scenario_module_sha256sum" => "4af1d0820e7dd012b1749d75c73d69320546b862be7c81c42fa6d4db79b548ac",
      "func.time_end"                  => 1531658415.8868,
      "func.time_factor"               => 1000000,
      "func.time_start"                => 1531658415.78438,
      "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
      "table.field_units"              => [undef, "/s", "\x{3BC}s"],
      "table.fields"                   => ["arg_str", "rate", "time", "vs_slowest", "errors", "samples"],
    },
  ],
];

1;
# ABSTRACT: Benchmark parsing with DateTime::Format::Duration::ISO8601

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

